@@ -120,7 +120,7 @@ stop('Unexpected parameter length for "cat.fontface"'); }
 	else if (length(cat.fontfamily) != 4) { flog.error('Unexpected parameter length for "cat.fontfamily"',name='VennDiagramLogger')
 stop('Unexpected parameter length for "cat.fontfamily"'); }
 
-	if (!(class(cat.just) == 'list' & length(cat.just) == 4 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2 & length(cat.just[[3]]) == 2 & length(cat.just[[4]]) == 2)) { flog.error('Unexpected parameter format for "cat.just"',name='VennDiagramLogger')
+	if (!(is.list(cat.just) && length(cat.just) == 4 && length(cat.just[[1]]) == 2 && length(cat.just[[2]]) == 2 && length(cat.just[[3]]) == 2 && length(cat.just[[4]]) == 2)) { flog.error('Unexpected parameter format for "cat.just"',name='VennDiagramLogger')
 stop('Unexpected parameter format for "cat.just"'); }
 	cat.pos <- cat.pos + rotation.degree;
 	
@@ -187,7 +187,7 @@ stop(paste('Impossible:', areas.error[i], 'produces negative area'));
 
             ## figure out what function to use
             func = cex.prop
-            if(class(cex.prop) != 'function'){
+            if (!is(cex.prop, 'function')) {
                 if(cex.prop == 'lin'){
                     func = function(x) x
                 }
